@@ -1,6 +1,7 @@
 from typing import Optional
 
 from datalabs.tasks import (
+    argument_pair_extraction,
     cloze,
     conditional_generation,
     coreference_resolution,
@@ -12,6 +13,7 @@ from datalabs.tasks import (
     multilabel_classification,
     poetry,
     question_answering,
+    ranking,
     retrieval,
     semantic_parsing,
     sequence_labeling,
@@ -53,6 +55,7 @@ __all__ = [
     "tabular_regression",
     "multilabel_classification",
     "text_pair_classification",
+    "argument_pair_extraction",
     "cloze",
     "text_editing",
     "TaskTemplate",
@@ -61,6 +64,7 @@ __all__ = [
     "poetry",
     "register_task",
     "TASK_REGISTRY",
+    "ranking",
     "get_logger",
 ]
 
