@@ -44,21 +44,22 @@ class TaskType(str, Enum):
     qa_multiple_choice_qasc = "qa-multiple-choice-qasc"
     qa_multiple_choice_c3 = "qa-multiple-choice-c3"
     qa_multiple_choice_without_context = "qa-multiple-choice-without-context"
-    qa_open_domain = "qa_open_domain"
-    qa_bool_dureader = "qa_bool_dureader"
-    qa_extractive_dureader = "qa_extractive_dureader"
-    qa_multiple_choice_nlpec = "qa_multiple_choice_nlpec"
+    qa_open_domain = "qa-open-domain"
+    qa_bool_dureader = "qa-bool-dureader"
+    qa_extractive_dureader = "qa-extractive-dureader"
+    qa_multiple_choice_nlpec = "qa-multiple-choice-nlpec"
+    qa_table_text_hybrid = "qa-table-text-hybrid"
     sequence_labeling = "sequence-labeling"
     named_entity_recognition = "named-entity-recognition"
     word_segmentation = "word-segmentation"
     chunking = "chunking"
     part_of_speech = "part-of-speech"
     opinion_target_extraction = "opinion-target-extraction"
-    event_extraction = "event_extraction"
-    event_entity_extraction = "event_entity_extraction"
-    event_arguments_extraction = "event_arguments_extraction"
-    event_relation_extraction_causality = "event_relation_extraction_causality"
-    entity_relation_extraction = "entity_relation_extraction"
+    event_extraction = "event-extraction"
+    event_entity_extraction = "event-entity-extraction"
+    event_arguments_extraction = "event-arguments-extraction"
+    event_relation_extraction_causality = "event-relation-extraction-causality"
+    entity_relation_extraction = "entity-relation-extraction"
     semantic_parsing = "semantic-parsing"
     text_to_sql = "text-to-sql"
     span_relation_prediction = "span-relation-prediction"
@@ -82,14 +83,14 @@ class TaskType(str, Enum):
     grammatical_judgment = "grammatical-judgment"
     question_classification = "question-classification"
     topic_classification = "topic-classification"
-    question_answering_classification = "question_answering_classification"
+    question_answering_classification = "question-answering-classification"
     text_pair_classification = "text-pair-classification"
     natural_language_inference = "natural-language-inference"
     paraphrase_identification = "paraphrase-identification"
     keyword_recognition = "keyword-recognition"
     text_similarity = "text-similarity"
     multilabel_classification = "multilabel-classification"
-    question_answering_matching = "question_answering_matching"
+    question_answering_matching = "question-answering-matching"
     opinion_summarization = "opinion-summarization"
     multi_ref_query_summarization = "multi-ref-query-summarization"
     aspect_summarization = "aspect-summarization"
@@ -108,10 +109,13 @@ class TaskType(str, Enum):
     cloze_generative = "cloze-generative"
     cloze_documents = "cloze_documents"
     text_editing = "text-editing"
+    claim_stance_classification = "claim-stance-classification"
     grammatical_error_correction = "grammatical-error-correction"
     grammatical_error_correction_m2 = "grammatical-error-correction-m2"
     essay_writing = "essay-writing"
+    argument_pair_extraction = "argument-pair-extraction"
     dialogue = "dialogue"
+    argument_pair_identification = "argument-pair-identification"
     knowledge_driven_dialogue = "knowledge-driven-dialogue"
     task_oriented_dialogue = "task-oriented-dialogue"
     dialogue_emotion_action_tracking = "dialogue-emotion-action-tracking"
